@@ -76,9 +76,6 @@ public:
     ParserPrivate()
     {
         defaultdir_ = QStandardPaths::writableLocation(QStandardPaths::TempLocation);
-        current_ = nullptr;
-        deleteDevice_ = false;
-        device_ = nullptr;
         message_ = new KTNEFMessage;
     }
     ~ParserPrivate()
@@ -541,7 +538,7 @@ bool KTNEFParser::openFile(const QString &filename) const
     d->deleteDevice();
     delete d->message_;
     d->message_ = new KTNEFMessage();
-    QFile *file = new QFile(filename);
+    auto *file = new QFile(filename);
     d->device_ = file;
     d->deleteDevice_ = true;
     if (!file->exists()) {
